@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -14,7 +14,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -70,7 +70,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -88,17 +88,16 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -119,7 +118,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
@@ -130,7 +129,6 @@
 
 #include "nsock.h"
 #include <vector>
-#include "nmap.h"
 #include "libnetutil/npacket.h"
 
 /* Mention some classes here so we don't have to place the declarations in
@@ -141,6 +139,7 @@ class FPProbe;
 
 class Target;
 class FingerPrintResultsIPv6;
+struct FingerMatch;
 
 /******************************************************************************
  * CONSTANT DEFINITIONS                                                       *
@@ -393,6 +392,7 @@ class FPHost {
   unsigned int probes_sent;       /* Number of FPProbes sent (not counting retransmissions)       */
   unsigned int probes_answered;   /* Number of FPResponses received                               */
   unsigned int probes_unanswered; /* Number of FPProbes that timedout (after all retransmissions) */
+  bool incomplete_fp;             /* True if we were unable to send all attempted probes          */
   bool detection_done;            /* True if the OS detection process has been completed.         */
   bool timedprobes_sent;          /* True if the probes that have timing requirements were sent   */
   Target *target_host;            /* Info about the host to fingerprint                           */
@@ -425,11 +425,12 @@ class FPHost {
   virtual int schedule() = 0;
   virtual int callback(const u8 *pkt, size_t pkt_len, const struct timeval *tv) = 0;
   const struct sockaddr_storage *getTargetAddress();
+  void fail_one_probe();
 
 };
 
 /* This class represents IPv6 hosts to be fingerprinted. The class performs
- * OS detection asynchronously. To use it, shedule() must be called at regular
+ * OS detection asynchronously. To use it, schedule() must be called at regular
  * intervals until done() returns true. After that, status() will indicate
  * whether the host was successfully matched with a particular OS or not. */
 class FPHost6 : public FPHost {
@@ -471,3 +472,4 @@ std::vector<FingerMatch> load_fp_matches();
 
 
 #endif /* __FPENGINE_H__ */
+
