@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -14,7 +14,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -70,7 +70,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -88,17 +88,16 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -119,7 +118,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 /* This code was originally part of the Nping tool.                        */
@@ -568,7 +567,7 @@ u16 IPv4Header::getSum() const {
 int IPv4Header::setDestinationAddress(u32 d){
   h.ip_dst.s_addr =  d;
   return OP_SUCCESS;
-} /* End of getDestinationAddress() */
+} /* End of setDestinationAddress() */
 
 /** Sets destination IP address.
  *  @warning Destination IP must be supplied in NETWORK byte order. Usually
@@ -577,7 +576,7 @@ int IPv4Header::setDestinationAddress(u32 d){
 int IPv4Header::setDestinationAddress(struct in_addr d){
   h.ip_dst=d;
   return OP_SUCCESS;
-} /* End of getDestinationAddress() */
+} /* End of setDestinationAddress() */
 
 
 /** Returns destination IP address.
@@ -665,7 +664,7 @@ int IPv4Header::setOpts(const char *txt){
 int IPv4Header::setOpts(u8 *opts_buff,  u32 opts_len){
   if(opts_buff==NULL || opts_len==0)
    return OP_FAILURE;
-  assert(opts_len<=MAX_IP_OPTIONS_LEN); /* Max lenght for IP options */
+  assert(opts_len<=MAX_IP_OPTIONS_LEN); /* Max length for IP options */
   memcpy(this->h.options, opts_buff, opts_len);
   this->ipoptlen=opts_len;
   this->length += opts_len;
@@ -682,7 +681,8 @@ const u8 *IPv4Header::getOpts() const {
 const u8 *IPv4Header::getOpts(int *len) const {
   if(len==NULL)
     printf("getOpts(): NULL pointer supplied.\n");
-  *len=ipoptlen;
+  else
+    *len=ipoptlen;
   return h.options;
 } /* End of getOpts() */
 
