@@ -7,72 +7,103 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
- * Foundation; Version 2 with the clarifications and exceptions described  *
- * below.  This guarantees your right to use, modify, and redistribute     *
- * this software under certain conditions.  If you wish to embed Nmap      *
- * technology into proprietary software, we sell alternative licenses      *
- * (contact sales@insecure.com).  Dozens of software vendors already       *
- * license Nmap technology such as host discovery, port scanning, OS       *
- * detection, version detection, and the Nmap Scripting Engine.            *
+ * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+ * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+ * modify, and redistribute this software under certain conditions.  If    *
+ * you wish to embed Nmap technology into proprietary software, we sell    *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+ * vendors already license Nmap technology such as host discovery, port    *
+ * scanning, OS detection, version detection, and the Nmap Scripting       *
+ * Engine.                                                                 *
  *                                                                         *
- * Note that the GPL places important restrictions on "derived works", yet *
- * it does not provide a detailed definition of that term.  To avoid       *
+ * Note that the GPL places important restrictions on "derivative works",  *
+ * yet it does not provide a detailed definition of that term.  To avoid   *
  * misunderstandings, we interpret that term as broadly as copyright law   *
  * allows.  For example, we consider an application to constitute a        *
- * "derivative work" for the purpose of this license if it does any of the *
- * following:                                                              *
- * o Integrates source code from Nmap                                      *
- * o Reads or includes Nmap copyrighted data files, such as                *
- *   nmap-os-db or nmap-service-probes.                                    *
- * o Executes Nmap and parses the results (as opposed to typical shell or  *
- *   execution-menu apps, which simply display raw Nmap output and so are  *
- *   not derivative works.)                                                *
- * o Integrates/includes/aggregates Nmap into a proprietary executable     *
- *   installer, such as those produced by InstallShield.                   *
- * o Links to a library or executes a program that does any of the above   *
+ * derivative work for the purpose of this license if it does any of the   *
+ * following with any software or content covered by this license          *
+ * ("Covered Software"):                                                   *
  *                                                                         *
- * The term "Nmap" should be taken to also include any portions or derived *
- * works of Nmap, as well as other software we distribute under this       *
- * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
- * but is meant to clarify our interpretation of derived works with some   *
- * common examples.  Our interpretation applies only to Nmap--we don't     *
- * speak for other people's GPL works.                                     *
+ * o Integrates source code from Covered Software.                         *
  *                                                                         *
- * If you have any questions about the GPL licensing restrictions on using *
- * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
- * we also offer alternative license to integrate Nmap into proprietary    *
- * applications and appliances.  These contracts have been sold to dozens  *
- * of software vendors, and generally include a perpetual license as well  *
- * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+ * or nmap-service-probes.                                                 *
  *                                                                         *
- * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+ * o Is designed specifically to execute Covered Software and parse the    *
+ * results (as opposed to typical shell or execution-menu apps, which will *
+ * execute anything you tell them to).                                     *
+ *                                                                         *
+ * o Includes Covered Software in a proprietary executable installer.  The *
+ * installers produced by InstallShield are an example of this.  Including *
+ * Nmap with other software in compressed or archival form does not        *
+ * trigger this provision, provided appropriate open source decompression  *
+ * or de-archiving software is widely available for no charge.  For the    *
+ * purposes of this license, an installer is considered to include Covered *
+ * Software even if it actually retrieves a copy of Covered Software from  *
+ * another source during runtime (such as by downloading it from the       *
+ * Internet).                                                              *
+ *                                                                         *
+ * o Links (statically or dynamically) to a library which does any of the  *
+ * above.                                                                  *
+ *                                                                         *
+ * o Executes a helper program, module, or script to do any of the above.  *
+ *                                                                         *
+ * This list is not exclusive, but is meant to clarify our interpretation  *
+ * of derived works with some common examples.  Other people may interpret *
+ * the plain GPL differently, so we consider this a special exception to   *
+ * the GPL that we apply to Covered Software.  Works which meet any of     *
+ * these conditions must conform to all of the terms of this license,      *
+ * particularly including the GPL Section 3 requirements of providing      *
+ * source code and allowing free redistribution of the work as a whole.    *
+ *                                                                         *
+ * As another special exception to the GPL terms, Insecure.Com LLC grants  *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
  * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
- * linked combinations including the two. You must obey the GNU GPL in all *
- * respects for all of the code used other than OpenSSL.  If you modify    *
- * this file, you may extend this exception to your version of the file,   *
- * but you are not obligated to do so.                                     *
+ * linked combinations including the two.                                  *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * Any redistribution of Covered Software, including any derived works,    *
+ * must obey and carry forward all of the terms of this license, including *
+ * obeying all GPL rules and restrictions.  For example, source code of    *
+ * the whole work must be provided and free redistribution must be         *
+ * allowed.  All GPL references to "this License", are to be treated as    *
+ * including the terms and conditions of this license text as well.        *
+ *                                                                         *
+ * Because this license imposes special exceptions to the GPL, Covered     *
+ * Work may not be combined (even as part of a larger work) with plain GPL *
+ * software.  The terms, conditions, and exceptions of this license must   *
+ * be included as well.  This license is incompatible with some other open *
+ * source licenses as well.  In some cases we can relicense portions of    *
+ * Nmap or grant special permissions to use it in other open source        *
+ * software.  Please contact fyodor@nmap.org with any such requests.       *
+ * Similarly, we don't incorporate incompatible open source software into  *
+ * Covered Software without special permission from the copyright holders. *
+ *                                                                         *
+ * If you have any questions about the licensing restrictions on using     *
+ * Nmap in other works, are happy to help.  As mentioned above, we also    *
+ * offer alternative license to integrate Nmap into proprietary            *
+ * applications and appliances.  These contracts have been sold to dozens  *
+ * of software vendors, and generally include a perpetual license as well  *
+ * as providing for priority support and updates.  They also fund the      *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
+ *                                                                         *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
- * to nmap-dev@insecure.org for possible incorporation into the main       *
- * distribution.  By sending these changes to Fyodor or one of the         *
+ * to the dev@nmap.org mailing list for possible incorporation into the    *
+ * main distribution.  By sending these changes to Fyodor or one of the    *
  * Insecure.Org development mailing lists, or checking them into the Nmap  *
  * source code repository, it is understood (unless you specify otherwise) *
  * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -86,10 +117,9 @@
  *                                                                         *
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
- * General Public License v2.0 for more details at                         *
- * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
- * included with Nmap.                                                     *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+ * license file for more details (it's in a COPYING file included with     *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
  /* This code was originally part of the Nping tool.                        */
@@ -584,6 +614,35 @@ pkt_type_t *PacketParser::parse_packet(const u8 *pkt, size_t pktlen, bool eth_in
     }else{ // next_layer==APPLICATION_LAYER
         if(PKTPARSERDEBUG)puts("Next Layer=Application");
         if(curr_pktlen>0){
+            
+            /* If we get here it is possible that the packet is ARP but 
+             * we have no access to the original Ethernet header. We 
+             * determine if this header is ARP by checking its size 
+             * and checking for some common values. */          
+            if(arp.storeRecvData(curr_pkt, curr_pktlen)!=OP_FAILURE){
+              if( (arplen=arp.validate())!=OP_FAILURE){
+                if(arp.getHardwareType()==HDR_ETH10MB){
+                  if(arp.getProtocolType()==0x0800){
+                    if(arp.getHwAddrLen()==ETH_ADDRESS_LEN){
+                      if(arp.getProtoAddrLen()==IPv4_ADDRESS_LEN){
+                        this_packet[current_header].length=arplen;
+                        this_packet[current_header++].type=HEADER_TYPE_ARP;
+                        arp.reset();
+                        curr_pkt+=arplen;
+                        curr_pktlen-=arplen;
+                        if(curr_pktlen>0){
+                            next_layer=APPLICATION_LAYER;
+                            expected=HEADER_TYPE_RAW_DATA;
+                        }else{
+                            finished=true;
+                        }
+                      }
+                    }
+                  }
+                }
+              }
+            }
+                      
             //if(expected==HEADER_TYPE_DNS){
             //}else if(expected==HEADER_TYPE_HTTP){
             //}... ETC
@@ -1007,9 +1066,40 @@ bool PacketParser::is_response(PacketElement *sent, PacketElement *rcvd){
     if( (sent=sent->getNextElement())==NULL)
       return false;
   
-  /* Make sure both packets have the same network layer and that it is IP */
+  /* Make sure both packets have the same network layer */
   if(rcvd->protocol_id()!=sent->protocol_id())
     return false;
+    
+  /* The packet could be ARP */
+  if(rcvd->protocol_id()==HEADER_TYPE_ARP){
+    ARPHeader *sent_arp=(ARPHeader *)sent;
+    ARPHeader *rcvd_arp=(ARPHeader *)rcvd;
+    switch(sent_arp->getOpCode()){
+      case OP_ARP_REQUEST:
+        if(rcvd_arp->getOpCode()==OP_ARP_REPLY){
+          /* TODO @todo: getTargetIP() and getSenderIP() should 
+           * either return struct in_addr or IPAddress but not u32. */
+          if(sent_arp->getTargetIP()==rcvd_arp->getSenderIP())
+            if(sent_arp->getSenderIP()==rcvd_arp->getTargetIP())
+              return true;
+        }
+        return false;
+      break;
+           
+      /* We only support ARP, not RARP or other weird stuff. Also, if 
+       * we didn't send a request, then we don't expect any response */
+      case OP_RARP_REQUEST:
+      case OP_DRARP_REQUEST:
+      case OP_INARP_REQUEST:
+      default:
+        return false;
+      break;
+    
+    }
+    return false;
+  }
+  
+  /* The packet is IPv4 or IPv6 */
   if(rcvd->protocol_id()!=HEADER_TYPE_IPv6 && rcvd->protocol_id()!=HEADER_TYPE_IPv4)
     return false;
   if(PKTPARSERDEBUG)printf("%s(): Both packets use IP.\n", __func__);
@@ -1204,7 +1294,7 @@ bool PacketParser::is_response(PacketElement *sent, PacketElement *rcvd){
             case ICMPv6_NODEINFORESP:
               if(sent_icmp6->getNodeInfoFlags() != inner_icmp6->getNodeInfoFlags() )
                 return false;
-              if( memcmp(sent_icmp6->getNonce(), inner_icmp6->getNonce(), NI_NONCE_LEN)!=0 )
+              if(sent_icmp6->getNonce() != inner_icmp6->getNonce())
                 return false;
               if(sent_icmp6->getQtype() != inner_icmp6->getQtype() )
                 return false;
@@ -1413,7 +1503,7 @@ bool PacketParser::is_response(PacketElement *sent, PacketElement *rcvd){
                * responses with the same Nonce value that we used in the query. */
               if(rcvd_icmp6->getType()!=ICMPv6_NODEINFORESP)
                 return false;
-              if( memcmp(sent_icmp6->getNonce(), rcvd_icmp6->getNonce(), NI_NONCE_LEN)!=0 )
+              if(sent_icmp6->getNonce() != rcvd_icmp6->getNonce())
                 return false;
             break;
 
@@ -1709,3 +1799,59 @@ bool PacketParser::is_response(PacketElement *sent, PacketElement *rcvd){
   if(PKTPARSERDEBUG)printf("%s(): The received packet was successfully matched with the sent packet.\n", __func__);
   return true;
 }
+
+/* Tries to find a transport layer header in the supplied chain of
+ * protocol headers. On success it returns a pointer to a PacketElement
+ * of one of these types:
+ * 
+ * HEADER_TYPE_TCP
+ * HEADER_TYPE_UDP
+ * HEADER_TYPE_ICMPv4 
+ * HEADER_TYPE_ICMPv6
+ * HEADER_TYPE_SCTP
+ * HEADER_TYPE_ARP
+ * 
+ * It returns NULL if no transport layer header is found.
+ * 
+ * Note that this method onyl understands IPv4, IPv6 (and its 
+ * extension headers) and Ethernet. If the supplied packet contains
+ * something different before the tranport layer, NULL will be returned.
+ * */
+PacketElement *PacketParser::find_transport_layer(PacketElement *chain){
+  PacketElement *aux=chain;
+  /* Traverse the chain of PacketElements */
+  while(aux!=NULL){
+    switch(aux->protocol_id()){
+      /* If we have a link or a network layer header, skip it. */
+      case HEADER_TYPE_IPv6_HOPOPT:
+      case HEADER_TYPE_IPv4:
+      case HEADER_TYPE_IPv6:
+      case HEADER_TYPE_IPv6_ROUTE:
+      case HEADER_TYPE_IPv6_FRAG:
+      case HEADER_TYPE_IPv6_NONXT:
+      case HEADER_TYPE_IPv6_OPTS:
+      case HEADER_TYPE_ETHERNET:
+      case HEADER_TYPE_IPv6_MOBILE:
+        aux=aux->getNextElement();
+      break;
+      
+      /* If we found the transport layer, return it. */
+      case HEADER_TYPE_TCP:
+      case HEADER_TYPE_UDP:
+      case HEADER_TYPE_ICMPv4:
+      case HEADER_TYPE_ICMPv6:
+      case HEADER_TYPE_SCTP:
+      case HEADER_TYPE_ARP:
+        return aux;
+      break;
+      
+      /* Otherwise, the packet contains headers we don't understand
+       * so we just return NULL to indicate that no valid transport 
+       * layer was found. */
+      default:
+        return NULL;
+      break;
+    }
+  }
+  return NULL;
+} /* End of find_transport_layer() */
