@@ -2,72 +2,103 @@
  * ncat_posix.c -- POSIX-specific functions.                               *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
- * Foundation; Version 2 with the clarifications and exceptions described  *
- * below.  This guarantees your right to use, modify, and redistribute     *
- * this software under certain conditions.  If you wish to embed Nmap      *
- * technology into proprietary software, we sell alternative licenses      *
- * (contact sales@insecure.com).  Dozens of software vendors already       *
- * license Nmap technology such as host discovery, port scanning, OS       *
- * detection, version detection, and the Nmap Scripting Engine.            *
+ * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+ * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+ * modify, and redistribute this software under certain conditions.  If    *
+ * you wish to embed Nmap technology into proprietary software, we sell    *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+ * vendors already license Nmap technology such as host discovery, port    *
+ * scanning, OS detection, version detection, and the Nmap Scripting       *
+ * Engine.                                                                 *
  *                                                                         *
- * Note that the GPL places important restrictions on "derived works", yet *
- * it does not provide a detailed definition of that term.  To avoid       *
+ * Note that the GPL places important restrictions on "derivative works",  *
+ * yet it does not provide a detailed definition of that term.  To avoid   *
  * misunderstandings, we interpret that term as broadly as copyright law   *
  * allows.  For example, we consider an application to constitute a        *
- * "derivative work" for the purpose of this license if it does any of the *
- * following:                                                              *
- * o Integrates source code from Nmap                                      *
- * o Reads or includes Nmap copyrighted data files, such as                *
- *   nmap-os-db or nmap-service-probes.                                    *
- * o Executes Nmap and parses the results (as opposed to typical shell or  *
- *   execution-menu apps, which simply display raw Nmap output and so are  *
- *   not derivative works.)                                                *
- * o Integrates/includes/aggregates Nmap into a proprietary executable     *
- *   installer, such as those produced by InstallShield.                   *
- * o Links to a library or executes a program that does any of the above   *
+ * derivative work for the purpose of this license if it does any of the   *
+ * following with any software or content covered by this license          *
+ * ("Covered Software"):                                                   *
  *                                                                         *
- * The term "Nmap" should be taken to also include any portions or derived *
- * works of Nmap, as well as other software we distribute under this       *
- * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
- * but is meant to clarify our interpretation of derived works with some   *
- * common examples.  Our interpretation applies only to Nmap--we don't     *
- * speak for other people's GPL works.                                     *
+ * o Integrates source code from Covered Software.                         *
  *                                                                         *
- * If you have any questions about the GPL licensing restrictions on using *
- * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
- * we also offer alternative license to integrate Nmap into proprietary    *
- * applications and appliances.  These contracts have been sold to dozens  *
- * of software vendors, and generally include a perpetual license as well  *
- * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+ * or nmap-service-probes.                                                 *
  *                                                                         *
- * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+ * o Is designed specifically to execute Covered Software and parse the    *
+ * results (as opposed to typical shell or execution-menu apps, which will *
+ * execute anything you tell them to).                                     *
+ *                                                                         *
+ * o Includes Covered Software in a proprietary executable installer.  The *
+ * installers produced by InstallShield are an example of this.  Including *
+ * Nmap with other software in compressed or archival form does not        *
+ * trigger this provision, provided appropriate open source decompression  *
+ * or de-archiving software is widely available for no charge.  For the    *
+ * purposes of this license, an installer is considered to include Covered *
+ * Software even if it actually retrieves a copy of Covered Software from  *
+ * another source during runtime (such as by downloading it from the       *
+ * Internet).                                                              *
+ *                                                                         *
+ * o Links (statically or dynamically) to a library which does any of the  *
+ * above.                                                                  *
+ *                                                                         *
+ * o Executes a helper program, module, or script to do any of the above.  *
+ *                                                                         *
+ * This list is not exclusive, but is meant to clarify our interpretation  *
+ * of derived works with some common examples.  Other people may interpret *
+ * the plain GPL differently, so we consider this a special exception to   *
+ * the GPL that we apply to Covered Software.  Works which meet any of     *
+ * these conditions must conform to all of the terms of this license,      *
+ * particularly including the GPL Section 3 requirements of providing      *
+ * source code and allowing free redistribution of the work as a whole.    *
+ *                                                                         *
+ * As another special exception to the GPL terms, Insecure.Com LLC grants  *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
  * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
- * linked combinations including the two. You must obey the GNU GPL in all *
- * respects for all of the code used other than OpenSSL.  If you modify    *
- * this file, you may extend this exception to your version of the file,   *
- * but you are not obligated to do so.                                     *
+ * linked combinations including the two.                                  *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * Any redistribution of Covered Software, including any derived works,    *
+ * must obey and carry forward all of the terms of this license, including *
+ * obeying all GPL rules and restrictions.  For example, source code of    *
+ * the whole work must be provided and free redistribution must be         *
+ * allowed.  All GPL references to "this License", are to be treated as    *
+ * including the terms and conditions of this license text as well.        *
+ *                                                                         *
+ * Because this license imposes special exceptions to the GPL, Covered     *
+ * Work may not be combined (even as part of a larger work) with plain GPL *
+ * software.  The terms, conditions, and exceptions of this license must   *
+ * be included as well.  This license is incompatible with some other open *
+ * source licenses as well.  In some cases we can relicense portions of    *
+ * Nmap or grant special permissions to use it in other open source        *
+ * software.  Please contact fyodor@nmap.org with any such requests.       *
+ * Similarly, we don't incorporate incompatible open source software into  *
+ * Covered Software without special permission from the copyright holders. *
+ *                                                                         *
+ * If you have any questions about the licensing restrictions on using     *
+ * Nmap in other works, are happy to help.  As mentioned above, we also    *
+ * offer alternative license to integrate Nmap into proprietary            *
+ * applications and appliances.  These contracts have been sold to dozens  *
+ * of software vendors, and generally include a perpetual license as well  *
+ * as providing for priority support and updates.  They also fund the      *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
+ *                                                                         *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
- * to nmap-dev@insecure.org for possible incorporation into the main       *
- * distribution.  By sending these changes to Fyodor or one of the         *
+ * to the dev@nmap.org mailing list for possible incorporation into the    *
+ * main distribution.  By sending these changes to Fyodor or one of the    *
  * Insecure.Org development mailing lists, or checking them into the Nmap  *
  * source code repository, it is understood (unless you specify otherwise) *
  * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -81,19 +112,20 @@
  *                                                                         *
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
- * General Public License v2.0 for more details at                         *
- * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
- * included with Nmap.                                                     *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+ * license file for more details (it's in a COPYING file included with     *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
 /* $Id$ */
 
-#include <assert.h>
-
 #include "ncat.h"
 
+#ifdef HAVE_LUA
+#include "ncat_lua.h"
+#endif
+
 char **cmdline_split(const char *cmdexec);
 
 /* fork and exec a child process with netexec. Close the given file descriptor
@@ -156,10 +188,19 @@ void netexec(struct fdinfo *info, char *cmdexec)
     int maxfd;
 
     if (o.debug) {
-        if (o.shellexec)
+        switch (o.execmode) {
+        case EXEC_SHELL:
             logdebug("Executing with shell: %s\n", cmdexec);
-        else
+            break;
+#ifdef HAVE_LUA
+        case EXEC_LUA:
+            logdebug("Executing as lua script: %s\n", cmdexec);
+            break;
+#endif
+        default:
             logdebug("Executing: %s\n", cmdexec);
+            break;
+        }
     }
 
     if (pipe(child_stdin) == -1 || pipe(child_stdout) == -1)
@@ -173,20 +214,38 @@ void netexec(struct fdinfo *info, char *cmdexec)
         close(child_stdin[1]);
         close(child_stdout[0]);
 
+        /* We might have turned off SIGPIPE handling in ncat_listen.c. Since
+           the child process SIGPIPE might mean that the connection got broken,
+           ignoring it could result in an infinite loop if the code here
+           ignores the error codes of read()/write() calls. So, just in case,
+           let's restore SIGPIPE so that writing to a broken pipe results in
+           killing the child process. */
+        Signal(SIGPIPE, SIG_DFL);
+
         /* rearrange stdin and stdout */
         Dup2(child_stdin[0], STDIN_FILENO);
         Dup2(child_stdout[1], STDOUT_FILENO);
 
-        if (o.shellexec) {
-            execl("/bin/sh", "sh", "-c", cmdexec, (void *) NULL);
-        } else {
-            char **cmdargs;
+        setup_environment(info);
 
+        switch (o.execmode) {
+        char **cmdargs;
+
+        case EXEC_SHELL:
+            execl("/bin/sh", "sh", "-c", cmdexec, (void *) NULL);
+            break;
+#ifdef HAVE_LUA
+        case EXEC_LUA:
+            lua_run();
+            break;
+#endif
+        default:
             cmdargs = cmdline_split(cmdexec);
             execv(cmdargs[0], cmdargs);
+            break;
         }
 
-        /* exec failed.*/
+        /* exec failed. */
         die("exec");
     }
 
@@ -198,7 +257,7 @@ void netexec(struct fdinfo *info, char *cmdexec)
         maxfd = info->fd;
 
     /* This is the parent process. Enter a "caretaker" loop that reads from the
-       socket and writes to the suprocess, and reads from the subprocess and
+       socket and writes to the subprocess, and reads from the subprocess and
        writes to the socket. We exit the loop on any read error (or EOF). On a
        write error we just close the opposite side of the conversation. */
     crlf_state = 0;
@@ -276,34 +335,41 @@ char **cmdline_split(const char *cmdexec)
     ptr = cmdexec;
     while (*ptr) {
         // Find the start of the token
-        while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr)) ptr++;
-        if ('\0' == *ptr)     break;
+        while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr))
+            ptr++;
+        if ('\0' == *ptr)
+            break;
         max_tokens++;
         // Find the start of the whitespace again
-        while (('\0' != *ptr) && !isspace((int) (unsigned char) *ptr)) ptr++;
+        while (('\0' != *ptr) && !isspace((int) (unsigned char) *ptr))
+            ptr++;
     }
 
     /* The line is not empty so we've got something to deal with */
-    cmd_args = (char**)safe_malloc(sizeof(char*) * (max_tokens + 1));
-    cur_arg = (char*)Calloc(sizeof(char), strlen(cmdexec));
+    cmd_args = (char **) safe_malloc(sizeof(char *) * (max_tokens + 1));
+    cur_arg = (char *) Calloc(sizeof(char), strlen(cmdexec));
 
     /* Get and copy the tokens */
     ptr = cmdexec;
     while (*ptr) {
-        while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr)) ptr++;
-        if ('\0' == *ptr)     break;
+        while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr))
+            ptr++;
+        if ('\0' == *ptr)
+            break;
 
         while (('\0' != *ptr) && !isspace((int) (unsigned char) *ptr)) {
             if ('\\' == *ptr) {
                 ptr++;
-                if ('\0' == *ptr)   break;
+                if ('\0' == *ptr)
+                    break;
 
                 cur_arg[ptr_idx] = *ptr;
                 ptr_idx++;
                 ptr++;
 
                 if ('\\' != *(ptr - 1)) {
-                    while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr)) ptr++;
+                    while (('\0' != *ptr) && isspace((int) (unsigned char) *ptr))
+                        ptr++;
                 }
             } else {
                 cur_arg[ptr_idx] = *ptr;
@@ -327,6 +393,14 @@ char **cmdline_split(const char *cmdexec)
     return cmd_args;
 }
 
+int ncat_openlog(const char *logfile, int append)
+{
+    if (append)
+        return Open(logfile, O_WRONLY | O_CREAT | O_APPEND, 0664);
+    else
+        return Open(logfile, O_WRONLY | O_CREAT | O_TRUNC, 0664);
+}
+
 void set_lf_mode(void)
 {
     /* Nothing needed. */
@@ -344,7 +418,8 @@ int ssl_load_default_ca_certs(SSL_CTX *ctx)
         logdebug("Using system default trusted CA certificates and those in %s.\n", NCAT_CA_CERTS_PATH);
 
     /* Load distribution-provided defaults, if any. */
-    assert(SSL_CTX_set_default_verify_paths(ctx) > 0);
+    rc = SSL_CTX_set_default_verify_paths(ctx);
+    ncat_assert(rc > 0);
 
     /* Also load the trusted certificates we ship. */
     rc = SSL_CTX_load_verify_locations(ctx, NCAT_CA_CERTS_PATH, NULL);
@@ -358,3 +433,8 @@ int ssl_load_default_ca_certs(SSL_CTX *ctx)
     return 0;
 }
 #endif
+
+int setenv_portable(const char *name, const char *value)
+{
+    return setenv(name, value, 1);
+}
