@@ -2,72 +2,103 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2012 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 with the clarifications and exceptions described  *
-# * below.  This guarantees your right to use, modify, and redistribute     *
-# * this software under certain conditions.  If you wish to embed Nmap      *
-# * technology into proprietary software, we sell alternative licenses      *
-# * (contact sales@insecure.com).  Dozens of software vendors already       *
-# * license Nmap technology such as host discovery, port scanning, OS       *
-# * detection, version detection, and the Nmap Scripting Engine.            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
 # *                                                                         *
-# * Note that the GPL places important restrictions on "derived works", yet *
-# * it does not provide a detailed definition of that term.  To avoid       *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
 # * misunderstandings, we interpret that term as broadly as copyright law   *
 # * allows.  For example, we consider an application to constitute a        *
-# * "derivative work" for the purpose of this license if it does any of the *
-# * following:                                                              *
-# * o Integrates source code from Nmap                                      *
-# * o Reads or includes Nmap copyrighted data files, such as                *
-# *   nmap-os-db or nmap-service-probes.                                    *
-# * o Executes Nmap and parses the results (as opposed to typical shell or  *
-# *   execution-menu apps, which simply display raw Nmap output and so are  *
-# *   not derivative works.)                                                *
-# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
-# *   installer, such as those produced by InstallShield.                   *
-# * o Links to a library or executes a program that does any of the above   *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
 # *                                                                         *
-# * The term "Nmap" should be taken to also include any portions or derived *
-# * works of Nmap, as well as other software we distribute under this       *
-# * license such as Zenmap, Ncat, and Nping.  This list is not exclusive,   *
-# * but is meant to clarify our interpretation of derived works with some   *
-# * common examples.  Our interpretation applies only to Nmap--we don't     *
-# * speak for other people's GPL works.                                     *
+# * o Integrates source code from Covered Software.                         *
 # *                                                                         *
-# * If you have any questions about the GPL licensing restrictions on using *
-# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
-# * we also offer alternative license to integrate Nmap into proprietary    *
-# * applications and appliances.  These contracts have been sold to dozens  *
-# * of software vendors, and generally include a perpetual license as well  *
-# * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
 # *                                                                         *
-# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
-# * linked combinations including the two. You must obey the GNU GPL in all *
-# * respects for all of the code used other than OpenSSL.  If you modify    *
-# * this file, you may extend this exception to your version of the file,   *
-# * but you are not obligated to do so.                                     *
+# * linked combinations including the two.                                  *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
-# * to nmap-dev@insecure.org for possible incorporation into the main       *
-# * distribution.  By sending these changes to Fyodor or one of the         *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
 # * source code repository, it is understood (unless you specify otherwise) *
 # * that you are offering the Nmap Project (Insecure.Com LLC) the           *
@@ -81,10 +112,9 @@
 # *                                                                         *
 # * This program is distributed in the hope that it will be useful, but     *
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
-# * General Public License v2.0 for more details at                         *
-# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
-# * included with Nmap.                                                     *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -112,7 +142,6 @@ OPTIONS = ['address',
 REFRESH_RATE = 500
 
 
-
 class ControlWidget(BWVBox):
     """
     """
@@ -126,7 +155,6 @@ class ControlWidget(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -148,6 +176,7 @@ def try_set_tooltip_text(widget, text):
         # The set_tooltip_text method was introduced in PyGTK 2.12.
         pass
 
+
 class ControlAction(BWExpander):
     """
     """
@@ -161,7 +190,6 @@ class ControlAction(BWExpander):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -222,7 +250,6 @@ class ControlAction(BWExpander):
         self.__region_color.set_no_show_all(True)
         self.__region_color.hide()
 
-
     def __change_pointer(self, widget, pointer):
         """
         """
@@ -234,14 +261,12 @@ class ControlAction(BWExpander):
         else:
             self.__region_color.hide()
 
-
     def __change_region(self, widget):
         """
         """
         self.radialnet.set_region_color(self.__region_color.get_active())
 
 
-
 class ControlVariableWidget(gtk.DrawingArea):
     """
     """
@@ -276,7 +301,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         gobject.timeout_add(REFRESH_RATE, self.verify_value)
 
-
     def verify_value(self):
         """
         """
@@ -287,7 +311,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         return True
 
-
     def button_press(self, widget, event):
         """
         """
@@ -300,7 +323,6 @@ class ControlVariableWidget(gtk.DrawingArea):
             self.__active_increment = True
             self.__increment_value()
 
-
     def button_release(self, widget, event):
         """
         """
@@ -311,7 +333,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-
     def motion_notify(self, widget, event):
         """
         Drawing callback
@@ -322,7 +343,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         @rtype: boolean
         @return: Indicator of the event propagation
         """
-        if self.__active_increment == True:
+        if self.__active_increment:
 
             xc, yc = self.__center_of_widget
             x, _ = self.get_pointer()
@@ -332,7 +353,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-
     def expose(self, widget, event):
         """
         Drawing callback
@@ -350,7 +370,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         return True
 
-
     def __draw(self):
         """
         """
@@ -363,7 +382,7 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         # draw line
         self.context.set_line_width(1)
-        self.context.set_dash([1,2])
+        self.context.set_dash([1, 2])
         self.context.move_to(self.__radius,
                              yc + self.__radius)
         self.context.line_to(2 * xc - 5,
@@ -371,7 +390,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.stroke()
 
         # draw text
-        self.context.set_dash([1,0])
+        self.context.set_dash([1, 0])
         self.context.set_font_size(10)
 
         width = self.context.text_extents(self.__variable_name)[2]
@@ -389,7 +408,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.arc(xc + self.__pointer_position,
                          yc + self.__radius,
                          self.__radius, 0, 2 * math.pi)
-        if self.__active_increment == True:
+        if self.__active_increment:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
         else:
             self.context.set_source_rgb(1.0, 1.0, 1.0)
@@ -397,18 +416,13 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.stroke()
 
-
     def __button_is_clicked(self, pointer):
         """
         """
         xc, yc = self.__center_of_widget
         center = (xc, yc + self.__radius)
 
-        if geometry.is_in_circle(pointer, 6, center) == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, 6, center)
 
     def __increment_value(self):
         """
@@ -417,25 +431,22 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-        if self.__active_increment == True:
+        if self.__active_increment:
 
             gobject.timeout_add(self.__increment_time,
                                 self.__increment_value)
 
-
     def set_value_function(self, value):
         """
         """
         self.__value = value
 
-
     def set_update_function(self, update):
         """
         """
         self.__update = update
 
 
-
 class ControlVariable(BWHBox):
     """
     """
@@ -454,7 +465,6 @@ class ControlVariable(BWHBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -485,14 +495,12 @@ class ControlVariable(BWHBox):
         self.bw_pack_start_expand_fill(self.__control)
         self.bw_pack_start_noexpand_nofill(self.__right_button)
 
-
     def __pressed(self, widget, increment):
         """
         """
         self.__increment = True
         self.__increment_function(increment)
 
-
     def __increment_function(self, increment):
         """
         """
@@ -505,15 +513,12 @@ class ControlVariable(BWHBox):
                                 self.__increment_function,
                                 increment)
 
-
     def __released(self, widget):
         """
         """
         self.__increment = False
 
 
-
-
 class ControlFisheye(BWVBox):
     """
     """
@@ -528,7 +533,6 @@ class ControlFisheye(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -575,7 +579,6 @@ class ControlFisheye(BWVBox):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_fisheye)
 
-
     def __update_fisheye(self):
         """
         """
@@ -617,7 +620,6 @@ class ControlFisheye(BWVBox):
 
         return True
 
-
     def active_fisheye(self):
         """
         """
@@ -625,13 +627,11 @@ class ControlFisheye(BWVBox):
         self.__change_ring()
         self.__change_interest()
 
-
     def deactive_fisheye(self):
         """
         """
         self.radialnet.set_fisheye(False)
 
-
     def __change_ring(self, widget=None):
         """
         """
@@ -640,7 +640,6 @@ class ControlFisheye(BWVBox):
         else:
             self.__ring.set_value(self.radialnet.get_fisheye_ring())
 
-
     def __change_interest(self, widget=None):
         """
         """
@@ -649,7 +648,6 @@ class ControlFisheye(BWVBox):
         else:
             self.__interest.set_value(self.radialnet.get_fisheye_interest())
 
-
     def __change_spread(self, widget=None):
         """
         """
@@ -659,7 +657,6 @@ class ControlFisheye(BWVBox):
             self.__spread.set_value(self.radialnet.get_fisheye_spread())
 
 
-
 class ControlInterpolation(BWExpander):
     """
     """
@@ -672,14 +669,14 @@ class ControlInterpolation(BWExpander):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
         self.__vbox = BWVBox()
 
         self.__cartesian_radio = gtk.RadioButton(None, _('Cartesian'))
-        self.__polar_radio = gtk.RadioButton(self.__cartesian_radio, _('Polar'))
+        self.__polar_radio = gtk.RadioButton(
+                self.__cartesian_radio, _('Polar'))
         self.__cartesian_radio.connect('toggled',
                                        self.__change_system,
                                        INTERPOLATION_CARTESIAN)
@@ -710,7 +707,6 @@ class ControlInterpolation(BWExpander):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_animation)
 
-
     def __update_animation(self):
         """
         """
@@ -724,7 +720,6 @@ class ControlInterpolation(BWExpander):
 
         return True
 
-
     def __change_system(self, widget, value):
         """
         """
@@ -738,7 +733,6 @@ class ControlInterpolation(BWExpander):
             else:
                 self.__polar_radio.set_active(True)
 
-
     def __change_frames(self, widget):
         """
         """
@@ -746,7 +740,6 @@ class ControlInterpolation(BWExpander):
             self.__frames.set_value(self.radialnet.get_number_of_frames())
 
 
-
 class ControlLayout(BWExpander):
     """
     """
@@ -759,7 +752,6 @@ class ControlLayout(BWExpander):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -780,7 +772,6 @@ class ControlLayout(BWExpander):
 
         self.__check_layout()
 
-
     def __check_layout(self):
         """
         """
@@ -792,14 +783,12 @@ class ControlLayout(BWExpander):
 
         return True
 
-
     def __force_update(self, widget):
         """
         """
         self.__fisheye_ring = self.radialnet.get_fisheye_ring()
         self.radialnet.update_layout()
 
-
     def __change_layout(self, widget):
         """
         """
@@ -810,7 +799,6 @@ class ControlLayout(BWExpander):
             self.__check_layout()
 
 
-
 class ControlRingGap(BWVBox):
     """
     """
@@ -823,7 +811,6 @@ class ControlRingGap(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -847,7 +834,6 @@ class ControlRingGap(BWVBox):
         self.bw_pack_start_noexpand_nofill(self.__radius)
         self.bw_pack_start_noexpand_nofill(self.__lower_hbox)
 
-
     def __change_lower(self, widget):
         """
         """
@@ -855,7 +841,6 @@ class ControlRingGap(BWVBox):
             self.__adjustment.set_value(self.radialnet.get_min_ring_gap())
 
 
-
 class ControlOptions(BWScrolledWindow):
     """
     """
@@ -871,7 +856,6 @@ class ControlOptions(BWScrolledWindow):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -912,23 +896,23 @@ class ControlOptions(BWScrolledWindow):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_options)
 
-
     def __update_options(self):
         """
         """
         model = self.__liststore
 
         model[OPTIONS.index('address')][0] = self.radialnet.get_show_address()
-        model[OPTIONS.index('hostname')][0] = self.radialnet.get_show_hostname()
+        model[OPTIONS.index('hostname')][0] = \
+                self.radialnet.get_show_hostname()
         model[OPTIONS.index('icon')][0] = self.radialnet.get_show_icon()
         model[OPTIONS.index('latency')][0] = self.radialnet.get_show_latency()
         model[OPTIONS.index('ring')][0] = self.radialnet.get_show_ring()
         model[OPTIONS.index('region')][0] = self.radialnet.get_show_region()
-        model[OPTIONS.index('slow in/out')][0] = self.radialnet.get_slow_inout()
+        model[OPTIONS.index('slow in/out')][0] = \
+                self.radialnet.get_slow_inout()
 
         return True
 
-
     def __change_option(self, cell, option, model):
         """
         """
@@ -957,7 +941,6 @@ class ControlOptions(BWScrolledWindow):
             self.radialnet.set_slow_inout(model[option][0])
 
 
-
 class ControlView(BWExpander):
     """
     """
@@ -971,7 +954,6 @@ class ControlView(BWExpander):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -995,7 +977,6 @@ class ControlView(BWExpander):
         self.bw_add(self.__vbox)
 
 
-
 class ControlNavigation(gtk.DrawingArea):
     """
     """
@@ -1016,12 +997,12 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.__move_position = (0, 0)
         self.__move_addition = [(-1, 0),
-                                (-1,-1),
-                                ( 0,-1),
-                                ( 1,-1),
-                                ( 1, 0),
-                                ( 1, 1),
-                                ( 0, 1),
+                                (-1, -1),
+                                (0, -1),
+                                (1, -1),
+                                (1, 0),
+                                (1, 1),
+                                (0, 1),
                                 (-1, 1)]
 
         self.__move_factor = 1
@@ -1055,7 +1036,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.__rotate_node.set_coordinate(40, self.radialnet.get_rotation())
 
-
     def key_press(self, widget, event):
         """
         """
@@ -1065,7 +1045,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return True
 
-
     def key_release(self, widget, event):
         """
         """
@@ -1075,13 +1054,11 @@ class ControlNavigation(gtk.DrawingArea):
 
         return True
 
-
     def enter_notify(self, widget, event):
         """
         """
         return False
 
-
     def leave_notify(self, widget, event):
         """
         """
@@ -1089,7 +1066,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def button_press(self, widget, event):
         """
         Drawing callback
@@ -1104,20 +1080,20 @@ class ControlNavigation(gtk.DrawingArea):
 
         direction = False
 
-        if self.__rotate_is_clicked(pointer) == True:
+        if self.__rotate_is_clicked(pointer):
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__rotating = True
 
         direction = self.__move_is_clicked(pointer)
 
-        if direction != None and self.__moving == None:
+        if direction is not None and self.__moving is None:
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__moving = direction
             self.__move_in_direction(direction)
 
-        if self.__center_is_clicked(pointer) == True:
+        if self.__center_is_clicked(pointer):
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__centering = True
@@ -1128,7 +1104,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def button_release(self, widget, event):
         """
         Drawing callback
@@ -1150,7 +1125,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def motion_notify(self, widget, event):
         """
         Drawing callback
@@ -1167,7 +1141,7 @@ class ControlNavigation(gtk.DrawingArea):
         status = not self.radialnet.is_in_animation()
         status = status and not self.radialnet.is_empty()
 
-        if self.__rotating == True and status:
+        if self.__rotating and status:
 
             r, t = self.__rotate_node.get_coordinate()
             t = math.degrees(math.atan2(yc - y, x - xc))
@@ -1182,7 +1156,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def expose(self, widget, event):
         """
         Drawing callback
@@ -1200,7 +1173,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw_rotate_control(self):
         """
         """
@@ -1220,17 +1192,17 @@ class ControlNavigation(gtk.DrawingArea):
         self.context.stroke()
 
         # draw arc
-        self.context.set_dash([1,2])
+        self.context.set_dash([1, 2])
         self.context.arc(xc, yc, 40, 0, 2 * math.pi)
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.set_line_width(1)
         self.context.stroke()
 
         # draw node
-        self.context.set_dash([1,0])
+        self.context.set_dash([1, 0])
         self.context.arc(xc + x, yc - y, self.__rotate_radius, 0, 2 * math.pi)
 
-        if self.__rotating == True:
+        if self.__rotating:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
 
         else:
@@ -1243,14 +1215,13 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw_move_control(self):
         """
         """
         xc, yc = self.__center_of_widget
         pc = PolarCoordinate()
 
-        self.context.set_dash([1,1])
+        self.context.set_dash([1, 1])
         self.context.arc(xc, yc, 23, 0, 2 * math.pi)
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.set_line_width(1)
@@ -1261,13 +1232,14 @@ class ControlNavigation(gtk.DrawingArea):
             pc.set_coordinate(23, 45 * i)
             x, y = pc.to_cartesian()
 
-            self.context.set_dash([1,1])
+            self.context.set_dash([1, 1])
             self.context.move_to(xc, yc)
             self.context.line_to(xc + x, yc - y)
             self.context.stroke()
 
-            self.context.set_dash([1,0])
-            self.context.arc(xc + x, yc - y, self.__move_radius, 0, 2 * math.pi)
+            self.context.set_dash([1, 0])
+            self.context.arc(
+                    xc + x, yc - y, self.__move_radius, 0, 2 * math.pi)
 
             if i == self.__moving:
                 self.context.set_source_rgb(0.0, 0.0, 0.0)
@@ -1280,7 +1252,7 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.context.arc(xc, yc, 6, 0, 2 * math.pi)
 
-        if self.__centering == True:
+        if self.__centering:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
         else:
             self.context.set_source_rgb(1.0, 1.0, 1.0)
@@ -1291,7 +1263,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw(self):
         """
         Drawing method
@@ -1307,11 +1278,10 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __move_in_direction(self, direction):
         """
         """
-        if self.__moving != None:
+        if self.__moving is not None:
 
             bx, by = self.__move_position
             ax, ay = self.__move_addition[direction]
@@ -1329,7 +1299,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __rotate_is_clicked(self, pointer):
         """
         """
@@ -1337,26 +1306,13 @@ class ControlNavigation(gtk.DrawingArea):
         xc, yc = self.__center_of_widget
 
         center = (xc + xn, yc - yn)
-        result = geometry.is_in_circle(pointer, self.__rotate_radius, center)
-
-        if result == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, self.__rotate_radius, center)
 
     def __center_is_clicked(self, pointer):
         """
         """
-        result = geometry.is_in_circle(pointer,
-                                       self.__move_radius,
-                                       self.__center_of_widget)
-
-        if result == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, self.__move_radius,
+                self.__center_of_widget)
 
     def __move_is_clicked(self, pointer):
         """
@@ -1370,13 +1326,7 @@ class ControlNavigation(gtk.DrawingArea):
             x, y = pc.to_cartesian()
 
             center = (xc + x, yc - y)
-            result = geometry.is_in_circle(pointer,
-                                           self.__move_radius,
-                                           center)
-
-            if result == True:
+            if geometry.is_in_circle(pointer, self.__move_radius, center):
                 return i
 
         return None
-
-
